execute method
The iterable, nested function that evaluates the entire FHIRPath expression one object at a time
Implementation
@override
List execute(List results, Map<String, dynamic> passed) => [
FhirDateTime(DateTime.now()),
];
The iterable, nested function that evaluates the entire FHIRPath expression one object at a time
@override
List execute(List results, Map<String, dynamic> passed) => [
FhirDateTime(DateTime.now()),
];