IterationContext class

Constructors

IterationContext()

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexValue ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thisValue ↔ dynamic
getter/setter pair
totalValue ↔ List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

current(Map<String, dynamic> passed) → IterationContext
withIterationContext(List iteratedFunction(IterationContext), Map<String, dynamic> passed) → List