FhirPathException class

Something went wrong while parsing or executing a FHIRPath expression.

Implemented types
Implementers

Constructors

FhirPathException(String message, {String? pathExpression, int? offset, Object? token, Object? cause, String? operation, dynamic arguments, List? collection, Object? context, Map? environment})

Properties

arguments → dynamic
The arguments to a function or operator at the time of the issue
final
cause → Object?
Exception which was the root cause
final
collection → List?
The intermediate results collection at the time of the issue
final
context → Object?
The original node that was passed to the evaluation engine before starting evaluation
final
environment → Map?
Environment which was present
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable message
final
offset → int?
Optional offset in the expression where the issue occurred
final
operation → String?
Which function or operator was causing the issue
final
pathExpression → String?
Which expression is having the issue
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Object?
Which token was causing the issue
final

Methods

copyWith({Object? context, Map? variables}) → FhirPathException
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toShortString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited